@@ -18,6 +18,7 @@ from collections import Counter
 
 import requests
 
+from bbcloud_python_sdk.Exceptions import FileDoesNotExistException
 from bbcloud_python_sdk.FileCache import FileCache
 
 logging.basicConfig(level=logging.WARNING)
@@ -33,11 +34,15 @@ def download_file(url, save_path):
     res = requests.get(url)
     if res.status_code == 200:
         basename = os.path.dirname(save_path)
+        if basename == '':
+            basename = './'
         if not os.path.exists(basename):
             os.makedirs(basename)
         with open(save_path, 'wb') as f:
             f.write(res.content)
-        return 'ok'
+        return save_path
+    elif res.status_code == 404:
+        raise FileDoesNotExistException('文件不存在：%s' % url)
     else:
         raise Exception('文件下载失败:%s:%s' % (res.status_code, url))
 
